<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package SuperBiz
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'superbiz' ); ?></a>
	<?php $show_topbar = superbiz_get_option( 'show_topbar' ); ?>
		<?php if ( true === $show_topbar ) : ?>
		<div class="top_bar">
			<div class="container">
				<div class="row">
					<div class="col-sm-12 col-md-8 text-center text-md-left">
						<?php 
							$topbar_address = superbiz_get_option( 'topbar_address' ); 
							$topbar_phone = superbiz_get_option( 'topbar_phone' );
							$topbar_email = superbiz_get_option( 'topbar_email' ); 
						?>
						<?php if ( ! empty( $topbar_address ) || ! empty( $topbar_phone ) || ! empty( $topbar_email ) ) { 
							$topbar_address = wp_kses_data( $topbar_address );
							$topbar_phone = wp_kses_data( $topbar_phone );
							$topbar_email = wp_kses_data( $topbar_email );
						?>
						<div class="top_address_box">
							<?php echo esc_html($topbar_address); ?>
						</div>
						<div class="top_phone_box">
							<?php if ( ! empty( $topbar_phone ) ) { ?>
								<a href="tel:<?php echo esc_attr($topbar_phone);?>">
									<?php echo esc_html($topbar_phone);?>
								</a>
							<?php } ?>
						</div>
						<div class="top_email_box">
							<?php if ( ! empty( $topbar_email ) ) { ?>
								<a href="mailto:<?php echo esc_attr($topbar_email);?>">
									<?php echo esc_html($topbar_email); ?>
								</a>
							<?php } ?>
						</div>
						<?php } ?>
					</div>
					<div class="col-sm-12 col-md-4 text-center text-md-right">
						<?php  if ( superbiz_get_option( 'show_social_menu' ) && has_nav_menu( 'superbiz_social' ) ) : ?>
			                <div class="social-menu">
			                    <?php  
			                	wp_nav_menu( array(
			                		'theme_location'  	=> 'superbiz_social',
			                		'container' 		=> false,
			                		'menu_class'      	=> 'menu',
			                		'depth'           	=> 1,
			            			'link_before' 		=> '<span class="screen-reader-text">',
									'link_after' 		=> '</span>',
			                	) );
			                	?>
			                </div><!-- .social-menu -->
			            <?php endif; ?>
					</div>
				</div>
			</div>
		</div>
		<?php endif; ?>
		<?php $header_opecity = superbiz_get_option( 'enable_header_opecity' );  
	
		?>

		<header id="masthead" class="site-header <?php 	echo $header_opecity  ? 'enable_header_opecity' : ' ';  ?>">
			<nav class="navbar navbar-expand-lg  navbar-dark ">
				<div class="container">
					  <div class="navbar-brand">
					  	<?php if ( ! has_custom_logo() ) { ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php 
						$superbiz_description = get_bloginfo( 'description', 'display' );
						if ( $superbiz_description || is_customize_preview() ) :
							?>
							<p class="site-description"><?php echo $superbiz_description; /* WPCS: xss ok. */ ?></p>
						<?php endif; ?>
						<?php } else {
							the_custom_logo();
						} ?><!-- end custom logo -->
					  </div>
					  <button class="navbar-toggler" type="button" data-toggle="<?php echo esc_attr("collapse") ?>" data-target="<?php echo esc_attr("#bs4navbar") ?>" aria-controls="<?php echo esc_attr("bs4navbar") ?>" aria-expanded="false" aria-label="<?php echo esc_attr("Toggle navigation") ?>">
					    <span class="navbar-toggler-icon"></span>
					  </button>
						<?php
					   wp_nav_menu(array(
					     'theme_location'  => 'superbiz_primary',
					     'container'       => 'div',
					     'container_id'    => 'bs4navbar',
					     'container_class' => 'collapse navbar-collapse',
					     'menu_id'         => false,
					     'menu_class'      => 'navbar-nav ml-auto',
					     'depth'           => 3,
					     'fallback_cb'     => 'WP_Bootstrap_Navwalker::fallback',
					     'walker'          => new WP_Bootstrap_Navwalker()
					  	) );
					   ?>
				</div>
			</nav>
		</header><!-- #masthead -->	
	<div id="content" class="site-content <?php if ( get_header_image() ) : ?> Has_header_img <?php endif; ?>">
