<?php
/**
 * SuperBiz Theme Customizer
 *
 * @package SuperBiz
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function superbiz_customize_register( $wp_customize ) {

	/* Custom panel type - used for multiple levels of panels */
	if ( class_exists( 'WP_Customize_Panel' ) ) {

		/**
		 * Class Superbiz_WP_Customize_Panel
		 */
		class Superbiz_WP_Customize_Panel extends WP_Customize_Panel {

			/**
			 * Panel
			 *
			 * @var $panel string Panel
			 */
			public $panel;

			/**
			 * Panel type
			 *
			 * @var $type string Panel type.
			 */
			public $type = 'superbiz_panel';

			/**
			 * Form the json
			 */
			public function json() {

				$array                   = wp_array_slice_assoc(
					(array) $this, array(
						'id',
						'description',
						'priority',
						'type',
						'panel',
					)
				);
				$array['title']          = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
				$array['content']        = $this->get_content();
				$array['active']         = $this->active();
				$array['instanceNumber'] = $this->instance_number;

				return $array;

			}

		}

	}

	// Load customize sanitize.
	require get_template_directory() . '/inc/customizer/sanitize.php';

	// Load customize option.
	require get_template_directory() . '/inc/customizer/options.php';

	

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.navbar-brand',
			'render_callback' => 'superbiz_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'superbiz_customize_partial_blogdescription',
		) );
	}
}
add_action( 'customize_register', 'superbiz_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function superbiz_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function superbiz_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function superbiz_customize_preview_js() {
	wp_enqueue_script( 'superbiz-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'superbiz_customize_preview_js' );

function superbiz_customizer_css() {
    ?>
    <style type="text/css">
	    h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6{
	    	font-family: var(--title-font);
			font-weight: var(--title-font-weight);
		  	
	    }
    	:root {
    		--primary:<?php echo esc_attr(get_theme_mod( 'primary' , '#2c2b2c')) ?>;
    		--secondary:<?php echo esc_attr(get_theme_mod( 'secondary' ,'#dd8808')) ?>;
		  	--header-text-color:<?php echo esc_attr(get_theme_mod( 'header_textcolor' ,'#fff')) ?>;
		  	--header-bg-color:<?php echo esc_attr(get_theme_mod( 'header_bg_color' ,'#000')) ?>;
		  	--link-color:#4A4A4A;
		  	--grey-color:#4A4A4A;
		  	--dark-color:#222222;
		  	--lite-grey:#2c2b2c;
		  	--grey:#2c2b2c;
		  	--body-color:#4A4A4A;
		  	--body-font: sans-serif;
		  	--title-font:sans-serif;
		  	--topbar_color:<?php echo esc_attr(get_theme_mod( 'topbar_color', '#ffffff')) ?>;
		  	--topbar_bg_color:<?php echo esc_attr(get_theme_mod( 'topbar_bg_color', '#2c2b2c')) ?>;
		  	--navbar-dark-color: <?php echo esc_attr(get_theme_mod( 'menu_link_color' , '#ffffff')) ?> ;
		  	--navbar-dark-hover-color:<?php echo esc_attr(get_theme_mod( 'menu_link_color_hover' , '#dd8808')) ?>;
		}
    </style>
    <?php
}
add_action( 'wp_head', 'superbiz_customizer_css' );