<?php
/**
 * Theme Options.
 *
 * @package SuperBiz
 */

$default = superbiz_get_default_theme_options();

// Add Theme Options Panel
$wp_customize->add_panel( 'theme_option_panel', array(
	'title'       => esc_html__( 'Theme Options', 'superbiz' ),
	'description' => esc_html__( 'SuperBiz Theme Options.', 'superbiz' ),
	'priority'    => 10,
) );

// Add topbar section
$wp_customize->add_section( 'section_header',
	array(
		'title'      => esc_html__( 'Top Bar Section', 'superbiz' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// topbar enable setting and control.
$wp_customize->add_setting( 'theme_options[show_topbar]',
	array(
	'default'           => $default['show_topbar'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'superbiz_sanitize_checkbox',
	)
);

$wp_customize->add_control( 'theme_options[show_topbar]',
	array(
	'label'    => esc_html__( 'Enable Topbar ', 'superbiz' ),
	'section'  => 'section_header',
	'type'     => 'checkbox',
	'priority' => 100,
	)
);

//adding setting for Top bar Background Color
$wp_customize->add_setting('topbar_bg_color', array(
	'default'        => $default['topbar_bg_color'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback'	=> 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'topbar_bg_color', array(
	'label'   => esc_html__('Top bar Background Color' , 'superbiz'),
	'section' => 'section_header',
    'settings'   => 'topbar_bg_color',
)));

//adding setting for Topbar Text Color
$wp_customize->add_setting('topbar_color', array(
	'default'        => $default['topbar_color'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback'	=> 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'topbar_color', array(
	'label'   => esc_html__('Top bar Text Color' , 'superbiz'),
	'section' => 'section_header',
    'settings'   => 'topbar_color',
)));

// topbar address
$wp_customize->add_setting( 'theme_options[topbar_address]',
	array(
		'default'           => $default['topbar_address'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control( 'theme_options[topbar_address]',
	array(
		'label'    => esc_html__( 'Address ', 'superbiz' ),
		'section'  => 'section_header',
		'type'     => 'text',
		'priority' => 100,
	)
);

// topbar phone No.
$wp_customize->add_setting( 'theme_options[topbar_phone]',
	array(
		'default'           => $default['topbar_phone'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control( 'theme_options[topbar_phone]',
	array(
		'label'    => esc_html__( 'Phone No. ', 'superbiz' ),
		'section'  => 'section_header',
		'type'     => 'text',
		'priority' => 100,
	)
);

// topbar email
$wp_customize->add_setting( 'theme_options[topbar_email]',
	array(
		'default'           => $default['topbar_email'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control( 'theme_options[topbar_email]',
	array(
		'label'    => esc_html__( 'Email ID', 'superbiz' ),
		'section'  => 'section_header',
		'type'     => 'text',
		'priority' => 100,
	)
);

// Add Header section
$wp_customize->add_section( 'section_color',
	array(
		'title'      => esc_html__( 'Header Section', 'superbiz' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// sticky header
$wp_customize->add_setting( 'theme_options[enable_sticky_header]',
	array(
		'default'           => $default['enable_sticky_header'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'superbiz_sanitize_checkbox',
	)
);

$wp_customize->add_control( 'theme_options[enable_sticky_header]',
	array(
	'label'    => esc_html__( 'Enable Sticky Header', 'superbiz' ),
	'section'  => 'section_color',
	'type'     => 'checkbox',
	'priority' => 10,
	)
);

// enable header opecity
$wp_customize->add_setting( 'theme_options[enable_header_opecity]',
	array(
	'default'           => $default['enable_header_opecity'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'superbiz_sanitize_checkbox',
	)
);

$wp_customize->add_control( 'theme_options[enable_header_opecity]',
	array(
	'label'    => esc_html__( 'Enable Header Opecity', 'superbiz' ),
	'section'  => 'section_color',
	'type'     => 'checkbox',
	'priority' => 10,
	)
);

//adding Menu Link Color
$wp_customize->add_setting('header_bg_color', array(
	'default'        => $default['header_bg_color'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback'	=> 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_bg_color', array(
	'label'   => esc_html__('Header Background Color' , 'superbiz'),
	'section' => 'section_color',
    'settings'   => 'header_bg_color',
)));


//adding Menu Link Color
$wp_customize->add_setting('menu_link_color', array(
	'default'        => $default['menu_link_color'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback'	=> 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menu_link_color', array(
	'label'   => esc_html__('Menu Link Color', 'superbiz'),
	'section' => 'section_color',
    'settings'   => 'menu_link_color',
)));

//adding menu_link_color_hover
$wp_customize->add_setting('menu_link_color_hover', array(
	 'default'        => $default['menu_link_color_hover'],
	 'capability'        => 'edit_theme_options',
	 'sanitize_callback'	=> 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menu_link_color_hover', array(
	'label'   => esc_html__('Menu Link Color Hover', 'superbiz'),
	'section' => 'section_color',
    'settings'   => 'menu_link_color_hover',
)));


//Theme Color
$wp_customize->add_setting('primary', array(
	'default'        => $default['primary'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback'	=> 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary', array(
	'label'   => esc_html__('Primary Color', 'superbiz'),
	'section' => 'colors',
	'settings'   => 'primary',
	'priority' => 1,
)));

//Theme secondary Color
$wp_customize->add_setting('secondary', array(
	'default'        => $default['secondary'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback'	=> 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary', array(
	'label'   => esc_html__('Secondary Color', 'superbiz'),
	'section' => 'colors',
	'settings'   => 'secondary',
	'priority' => 1,
)));

// Setting global_layout.
$wp_customize->add_section( 'superbiz_global_section',
	array(
		'title'      => esc_html__( 'Global Setting', 'superbiz' ),
		'description'       => esc_html__( 'Global Setting Options', 'superbiz' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting Blog Layout.
$wp_customize->add_setting( 'theme_options[global_layout]',
	array(
		'default'           => $default['global_layout'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'superbiz_sanitize_select',
	)
);
$wp_customize->add_control( 'theme_options[global_layout]',
	array(
		'label'    => esc_html__( 'Blog Layout', 'superbiz' ),
		'section'  => 'superbiz_global_section',
		'type'     => 'select',
		'choices'  => superbiz_get_global_layout_options(),
		'priority' => 100,
	)
);

// Setting Page Layout.
$wp_customize->add_setting( 'theme_options[page_layout]',
	array(
		'default'           => $default['page_layout'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'superbiz_sanitize_select',
	)
);
$wp_customize->add_control( 'theme_options[page_layout]',
	array(
		'label'    => esc_html__( 'Page Layout', 'superbiz' ),
		'section'  => 'superbiz_global_section',
		'type'     => 'select',
		'choices'  => superbiz_get_global_layout_options(),
		'priority' => 100,
	)
);

// Setting archive_layout.
$wp_customize->add_setting( 'theme_options[archive_layout]',
	array(
		'default'           => $default['archive_layout'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'superbiz_sanitize_select',
	)
);
$wp_customize->add_control( 'theme_options[archive_layout]',
	array(
		'label'    => esc_html__( 'Archive Layout', 'superbiz' ),
		'section'  => 'superbiz_global_section',
		'type'     => 'select',
		'choices'  => superbiz_get_archive_layout_options(),
		'priority' => 100,
	)
);

// Blog Section.
$wp_customize->add_section( 'section_blog',
	array(
		'title'      => esc_html__( 'Blog Options', 'superbiz' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);


// Setting excerpt_length.
$wp_customize->add_setting( 'theme_options[excerpt_length]',
	array(
		'default'           => $default['excerpt_length'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'superbiz_sanitize_positive_integer',
	)
);
$wp_customize->add_control( 'theme_options[excerpt_length]',
	array(
		'label'       => esc_html__( 'Excerpt Length', 'superbiz' ),
		'description' => esc_html__( 'in words', 'superbiz' ),
		'section'     => 'section_blog',
		'type'        => 'number',
		'priority'    => 100,
		'input_attrs' => array( 'min' => 1, 'max' => 200, 'style' => 'width: 55px;' ),
	)
);

// Setting read_more_text.
$wp_customize->add_setting( 'theme_options[read_more_text]',
	array(
		'default'           => $default['read_more_text'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'theme_options[read_more_text]',
	array(
		'label'    => esc_html__( 'Read More Text', 'superbiz' ),
		'section'  => 'section_blog',
		'type'     => 'text',
		'priority' => 100,
	)
);

// Footer Section.
$wp_customize->add_section( 'section_footer',
	array(
		'title'      => esc_html__( 'Footer Options', 'superbiz' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting copyright_text.
$wp_customize->add_setting( 'theme_options[copyright_text]',
	array(
		'default'           => $default['copyright_text'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_textarea_field',
		'transport'         => 'postMessage',
	)
);
$wp_customize->add_control( 'theme_options[copyright_text]',
	array(
		'label'    => esc_html__( 'Copyright Text', 'superbiz' ),
		'section'  => 'section_footer',
		'type'     => 'textarea',
		'priority' => 100,
	)
);





 
